@@ -1,17 +1,5 @@
-/* Copyright 2017-2018 ccls Authors
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================*/
+// Copyright 2017-2018 ccls Authors
+// SPDX-License-Identifier: Apache-2.0
 
 #include "indexer.hh"
 
@@ -461,9 +449,7 @@ public:
     }
     while (ret.size() && isspace(ret.back()))
       ret.pop_back();
-    if (StringRef(ret).endswith("*/"))
-      ret.resize(ret.size() - 2);
-    else if (StringRef(ret).endswith("\n/"))
+    if (StringRef(ret).endswith("*/") || StringRef(ret).endswith("\n/"))
       ret.resize(ret.size() - 2);
     while (ret.size() && isspace(ret.back()))
       ret.pop_back();
@@ -786,6 +772,7 @@ public:
         SourceRange sr = origD->getSourceRange();
         entity->def.spell = {use,
                              fromTokenRangeDefaulted(sm, lang, sr, fid, loc)};
+        entity->def.parent_kind = SymbolKind::File;
         getKind(cast<Decl>(sem_dc), entity->def.parent_kind);
       } else if (is_decl) {
         SourceRange sr = origD->getSourceRange();
