@@ -233,7 +233,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
       deleted = true;
     } else {
       if (vfs->stamp(path_to_index, *write_time, no_linkage ? 2 : 0))
-        reparse = no_linkage ? 2 : 1;
+        reparse = 1;
       if (request.path != path_to_index) {
         std::optional<int64_t> mtime1 = lastWriteTime(request.path);
         if (!mtime1)
@@ -260,8 +260,9 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
     do {
       std::unique_lock lock(getFileMutex(path_to_index));
       prev = rawCacheLoad(path_to_index);
-      if (!prev || cacheInvalid(vfs, prev.get(), path_to_index, entry.args,
-                                std::nullopt))
+      if (!prev || prev->no_linkage < no_linkage ||
+          cacheInvalid(vfs, prev.get(), path_to_index, entry.args,
+                       std::nullopt))
         break;
       if (track)
         for (const auto &dep : prev->dependencies) {
