@@ -1,17 +1,5 @@
-/* Copyright 2017-2018 ccls Authors
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================*/
+// Copyright 2017-2018 ccls Authors
+// SPDX-License-Identifier: Apache-2.0
 
 #include "project.hh"
 
@@ -538,7 +526,7 @@ Project::Entry Project::findEntry(const std::string &path, bool can_redirect,
       }
     }
 
-  bool append;
+  bool append = false;
   if (best_dot_ccls_args && !(append = appendToCDB(*best_dot_ccls_args)) &&
       !exact_match) {
     // If the first line is not %compile_commands.json, override the compdb
