@@ -1,17 +1,5 @@
-/* Copyright 2017-2018 ccls Authors
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================*/
+// Copyright 2017-2018 ccls Authors
+// SPDX-License-Identifier: Apache-2.0
 
 #include "sema_manager.hh"
 
@@ -231,7 +219,7 @@ class StoreDiags : public DiagnosticConsumer {
   }
 
 public:
-  StoreDiags(std::string path) : path(path) {}
+  StoreDiags(std::string path) : path(std::move(path)) {}
   std::vector<Diag> take() { return std::move(output); }
   bool isConcerned(const SourceManager &sm, SourceLocation l) {
     FileID fid = sm.getFileID(l);
